/**
 * mb-js-bridge-umd
 *
 */

var openPage = require('./openPage');
var checkAccess = require('./utils/checkAccess');

var p = window.prompt,
    s = JSON.stringify;

module.exports =  {

    /**
     * 当前 js bridge 版本号
     */
    version: process.env.VERSION,

    /**
     * 获取用户会话信息，成功返回会话信息对象，失败返回 false
     *
     * @since v4.0
     * @returns {{appName,sysType,networkType,SSID,MAC,appVersion,sysVersion,sessionId,lang,deviceId,domain}|boolean}
     */
    getSession: function () {
        try {
            return JSON.parse(p('JS_BRIDGE_GET_USER'));

        } catch (e) {
            return false;
        }
    },

    /**
     * 获取用户个人信息
     *
     * @since v4.0
     * @return {{userId,companyId,sessionId,name,avatar,level,golds,stars,diamonds,lifePoint,phone}|boolean}
     */
    getUserInfo: function () {
        try {
            return JSON.parse(p('JS_BRIDGE_GET_USER_INFO'));

        } catch (e) {
            return false;
        }
    },

    /**
     * 重登录，当用户信息过期时使用
     */
    sessionInvalid: function () {
        return p('JS_BRIDGE_SESSION_INVALID');
    },

    /**
     * 打开页面
     */
    openPage: openPage,

    /**
     *
     */
    setCallbackArgs: function (data) {
        var _args = {
            arguments: data
        };
        _args = s(_args);
        p('JS_BRIDGE_CALLBACK_ARGUMENTS', _args);
    },

    /**
     * 关闭 web 页面
     */
    closePage: function () {
        p('JS_BRIDGE_CLOSE_WINDOW');
    },

    /**
     * 埋点，新版本使用 eventsStatistic 代替
     *
     * @deprecated
     */
    track: function (obj) {
        p('JS_BRIDGE_EVENTS_STATISTIC', s(obj));
    },

    /**
     * 输出日志到 APP 控制台
     *
     * @deprecated 不再推荐使用
     */
    log: function (obj) {
        p('JS_BRIDGE_LOG', s(obj));
    },

    /**
     * 上传图片
     *
     * @since v4.0.0
     * @param {function(string)} callback
     */
    uploadImage: function (callback) {
        if (typeof callback !== 'function')
            throw new Error('UploadImage callback must be a function');

        window._$uploadPicHandler = function (ret) {
            try {
                var parsed = JSON.parse(ret);
                callback(parsed.imgUrl);

            } catch(e) {
                callback('');
            }
        };

        var result = p('JS_BRIDGE_UPLOAD_PIC', s({
            callback: '_$uploadPicHandler'
        }));

        if (result) {
            window._$uploadPicHandler(result);
        }
    },

    /**
     * 预览图片
     *
     * @since v4.0
     * @param {string|Array} imageUrl
     * @param {number|string} currentPos
     * @returns {*}
     */
    showImage: function (imageUrl, currentPos) {
        if (typeof imageUrl === 'object' && imageUrl.length && imageUrl.length > 0) {
            if (typeof currentPos === 'undefined')
                currentPos = 0;

            return p('JS_BRIDGE_OPEN_IMAGE_LIST', s({
                data: imageUrl,
                currImgUrl: (typeof currentPos === 'number' ? imageUrl[currentPos] : currentPos)
            }));
        }

        return p('JS_BRIDGE_OPEN_IMAGE', s({
            imgUrl: imageUrl
        }));
    },


    /**
     * 获取网络状态
     */
    getNetState: function (obj) {
        return p('JS_BRIDGE_NET_STATE', s(obj));
    },

    /**
     * 获取位置信息
     *
     * @return {object}
     */
    getLocation: function (obj) {
        return JSON.parse(p('JS_BRIDGE_LOCATION', s(obj)));
    },

    /**
     * 显示加载动画
     */
    showLoading: function() {
        return p('JS_BRIDGE_OPEN_LOADING');
    },

    /**
     * 隐藏加载动画
     */
    hideLoading: function() {
        return p('JS_BRIDGE_CLOSE_LOADING');
    },

    /**
     * 隐藏顶部标题栏
     *
     * @since v3.4.0
     */
    hideTitleBar: function () {
        return p('JS_BRIDGE_HIDE_TITLE_BAR');
    },

    /**
     * 分享
     *
     * @since v3.6.0
     * @param url
     * @param title
     * @param desc
     * @param image
     */
    share: function (url, title, desc, image) {
        return p('JS_BRIDGE_SHARE', s({
            url: url,
            title: title,
            desc: desc || '',
            image: image || ''
        }));
    },

    /**
     * 事件记录（埋点）
     *
     * @since v4.1.1
     * @param eventName
     * @param props
     * @returns {*}
     */
    eventsStatistic: function (eventName, props) {
        props = props || {};
        return p('JS_BRIDGE_EVENTS_STATISTIC', s({
            eventName: eventName,
            properties: props
        }));
    },

    /**
     * 获取解密数据值
     */
    getDecryptValue: function (key, data) {
         return p('JS_BRIDGE_DECRYPT_DATA', s({
            key: key,
            data: data
        }));
    },

    /**
     * 注册在关闭页面时执行的回调（目前仅用于安卓）
     *
     * @param callback
     */
    onClosePage: function (callback) {
        if (typeof callback !== 'function') {
            console.error('onCloseWindow callback must be a function');
            return;
        }

        window._$onCloseWindowEvent = function () {
            callback();
        };

        p('JS_BRIDGE_INTERCEPT_CLOSE_WINDOW_EVENT', '{"func":"_$onCloseWindowEvent"}');
    },

    /**
     * 打开选择联系人界面并选取一个联系人
     *
     * @return {boolean|{id, name, avatar}} 选择后选择联系人的基本信息，未选择时返回 false
     */
    getContact: function () {
        try {
            var ret = JSON.parse(p('JS_BRIDGE_SELECT_CONTACT'));
            if (!ret) return false;
            return ret;

        } catch (e) {
            return false;
        }
    }
};


/*
 * 判断当前页面权限，仅在权限允许时导出 Bridge 对象，否则将直接导出 undefined
 */
if (! checkAccess()) {
    module.exports = undefined;
}
