/**
 *
 * @author    Jerry Bendy
 * @since     17/1/4
 * @copyright MicroBenefits
 */

var extend = require('./utils/extend');



/**
 *
 * @param pageName
 * @param data
 * @returns {{}|void}
 */
function openPage (pageName, data) {

    var _args = JSON.stringify({
        pageName: pageName,
        data: data || {}
    });

    prompt('JS_BRIDGE_OPEN_PAGE', _args);
}


/**
 * 打开 web 页面
 *
 * @param url
 * @param title
 * @param otherParams
 */
openPage.webPage = function (url, title, otherParams) {

    openPage('WEB_PAGE', extend({
        url: url,
        title: title
    }, otherParams));

};


/**
 * 打开扫描二维码页面
 */
openPage.scanning = function () {
    openPage('SCANING');
};


/**
 * 打开 cLink
 */
openPage.cLink = function () {
    openPage('CLINK');
};


/**
 * 打开用户中心
 * @param userId 用户 ID
 * @param avatar 用户头像
 * @param realName 用户真实姓名
 */
openPage.userCenter = function (userId, avatar, realName) {
    openPage('USERCENTER', {
        userId: userId,
        avatar: avatar,
        realName: realName
    });
};


/**
 * 打开任务列表
 */
openPage.taskList = function () {
    openPage('TASK');
};


/**
 * 打开指定任务
 *
 * @param params 未封装的任务参数，详见文档
 */
openPage.task = function (params) {
    openPage('TASK_DETAIL', params);
};


/**
 * 打开课程集
 */
openPage.courseLibrary = function () {
    openPage('COURSE');
};


/**
 * 打开指定课程集
 *
 * @param id 课程集 ID
 * @param title 课程集名称
 * @param thumb 课程集缩略图
 * @param categoryName 课程集分类名（可选）
 */
openPage.courseSet = function (id, title, thumb, categoryName) {
    openPage('COURSE_SET_DETAIL', {
        id: id,
        title: title,
        thumb: thumb,
        categoryName: categoryName || ''
    });
};


/**
 * 打开挑战
 */
openPage.combat = function () {
    openPage('PK');
};


/**
 * 打开闯关达人
 */
openPage.quizMap = function () {
    openPage('QUIZ_MAP');
};


/**
 * 打开指定用户的用户中心
 *
 * @param userId
 * @param avatar
 * @param realName
 */
openPage.userCenter = function (userId, avatar, realName) {
    openPage('USERCENTER', {
        userId: userId,
        avatar: avatar,
        realName: realName
    });
};


/**
 * 打开热线
 */
openPage.hotLine = function () {
    openPage('HOTLINE');
};


/**
 * 打开摇一摇
 */
openPage.shake = function () {
    openPage('SHAKE');
};


/**
 * 打开附件
 *
 * @param params
 */
openPage.achievement = function (params) {
    openPage('ACHIEVEMENT', params);
};


/**
 * 打开评论模块
 *
 * @param topicId 评论 ID
 * @param title 评论标题
 * @param isAudit 是否审核，bool 值
 * @param limitTime 评论时间段，值为以中划线分隔的两个 UNIX 时间
 */
openPage.comment = function (topicId, title, isAudit, limitTime) {
    var param;
    if (typeof topicId === 'object' && !title && !isAudit && !limitTime) {
        param = topicId
    } else {
        param = {
            topicId: topicId,
            title: title,
            isAudit: isAudit,
            limitTime: limitTime || ''
        }
    }
    prompt('JS_BRIDGE_OPEN_COMMENT', JSON.stringify(param));
};


/**
 * 打开与指定联系人的聊天界面
 *
 * @param userId 好友的用户 ID
 * @param userName 好友昵称
 */
openPage.chat = function (userId, userName){
    openPage('PERSON_CHAT', {
        fId: userId,
        fName: userName
    });
};


/**
 * 打开指定群组的群聊界面
 *
 * @param groupId 群组 ID
 * @param groupName 群组名称
 */
openPage.groupChat = function (groupId, groupName) {
    openPage('GROUP_CHAT', {
        tId: groupId,
        tName: groupName
    });
};

module.exports = openPage;
